default_scale

Function default_scale 

pub fn default_scale(product: Product) -> DiscreteColorScale
Returns the default color scale for a given product.

This function selects an appropriate color scale based on the product type, using standard meteorological conventions.

ProductScale
ReflectivityNWS Reflectivity (dBZ)
VelocityDivergent Green-Red (-64 to +64 m/s)
SpectrumWidthSequential (0 to 30 m/s)
DifferentialReflectivityDivergent (-2 to +6 dB)
DifferentialPhaseSequential (0 to 360 deg)
CorrelationCoefficientSequential (0 to 1)
ClutterFilterPowerDivergent (-20 to +20 dB)