pub fn default_color_scale(product: Product) -> ColorScaleExpand description
Returns the default color scale for a product, wrapped in a ColorScale enum.
This is a convenience wrapper around default_scale that returns the
ColorScale enum directly, avoiding the need to call .into() at each call site.