pub fn get_specific_diff_phase_scale() -> DiscreteColorScaleExpand description
Returns a color scale for specific differential phase (KDP) data.
This sequential scale shows the rate of differential phase change, which correlates with rainfall rate. Higher KDP indicates heavier rain. Range: 0 to 10 degrees/km.
| KDP (deg/km) | Color | Meaning |
|---|---|---|
| 0-0.5 | Gray | Very light/no rain |
| 0.5-1.0 | Light Blue | Light rain |
| 1.0-2.0 | Blue | Light-moderate rain |
| 2.0-3.0 | Green | Moderate rain |
| 3.0-4.5 | Yellow | Moderate-heavy rain |
| 4.5-6.0 | Orange | Heavy rain |
| 6.0-10.0 | Red | Very heavy rain |