pub struct DiscreteColorScale { /* private fields */ }Expand description
A discrete color scale that maps value ranges to colors.
The scale works by finding the highest threshold that the input value exceeds, and returning the corresponding color. Levels are automatically sorted from highest to lowest threshold during construction.
Example
use nexrad_render::{ColorScaleLevel, DiscreteColorScale, Color};
let scale = DiscreteColorScale::new(vec![
ColorScaleLevel::new(0.0, Color::BLACK),
ColorScaleLevel::new(30.0, Color::rgb(0.0, 1.0, 0.0)),
ColorScaleLevel::new(50.0, Color::rgb(1.0, 0.0, 0.0)),
]);
// Values >= 50 return red, >= 30 return green, >= 0 return blackImplementations
Sourceimpl DiscreteColorScale
impl DiscreteColorScale
Sourcepub fn new(levels: Vec<ColorScaleLevel>) -> Self
pub fn new(levels: Vec<ColorScaleLevel>) -> Self
Creates a new discrete color scale from the given levels.
Levels are automatically sorted from highest to lowest threshold.
Sourcepub fn color(&self, value: f32) -> Color
pub fn color(&self, value: f32) -> Color
Returns the color for the given value.
Finds the highest threshold that the value exceeds and returns its color. If the value is below all thresholds, returns the color of the lowest threshold.
Sourcepub fn levels(&self) -> &[ColorScaleLevel]
pub fn levels(&self) -> &[ColorScaleLevel]
Returns the levels in this color scale (sorted highest to lowest).